==> qore-0.8.13.5.tar.bz2: qore-0.8.13.5/docs/library/html/_qore_8h.js <==
var _qore_8h =
[
    [ "QLO_CLEANUP_MASK", "_qore_8h.html#a775b595b770130199e61c8813e8dce0a", null ],
    [ "QLO_DISABLE_GARBAGE_COLLECTION", "_qore_8h.html#a9b922e3c858e60b05d73b49993e238f9", null ],
    [ "QLO_DISABLE_OPENSSL_CLEANUP", "_qore_8h.html#a37774985342ff0d9c2a0bbac6d8608dc", null ],
    [ "QLO_DISABLE_OPENSSL_INIT", "_qore_8h.html#ad8b4a4cef32dbf1bc16a68d5440c5c41", null ],
    [ "QLO_DISABLE_OPENSSL_INIT_CLEANUP", "_qore_8h.html#a1e6d8c51a0031fbc8647f8d7390e3213", null ],
    [ "QLO_DISABLE_SIGNAL_HANDLING", "_qore_8h.html#a07f9910d9930e441373dd9123b082bfd", null ],
    [ "QLO_DO_NOT_SEED_RNG", "_qore_8h.html#ae761fd26fc3572d87765af063a42ddd0", null ],
    [ "QLO_NONE", "_qore_8h.html#ab1b81a5f4b175388fb1b6d3c8bccabfb", null ],
    [ "qore_check_option", "_qore_8h.html#ad559fa513d4c8b65fb4ae91ae0a2889c", null ],
    [ "qore_cleanup", "_qore_8h.html#abec60f390fd78e61b7149586b6c00c58", null ],
    [ "qore_get_library_init_options", "_qore_8h.html#a51a38a72142d9e5c158c747e6c3c775c", null ],
    [ "qore_has_debug", "_qore_8h.html#a1d1b4cc872009e7d05c23a251bac4eb4", null ],
    [ "qore_init", "_qore_8h.html#ae984b2fa9be16c83531fb954485be4ac", null ],
    [ "qore_set_library_cleanup_options", "_qore_8h.html#acf783065ef11b039c5615b6386d8f05d", null ],
    [ "mpfrInfo", "_qore_8h.html#a850c8d5c2a644e5a98892bbb028ad0c4", null ],
    [ "qore_build_host", "_qore_8h.html#a355fb78ea8b9668ca413a9a802e3cdea", null ],
    [ "qore_build_number", "_qore_8h.html#a450bf7869a253a12612af9c6a564193c", null ],
    [ "qore_cflags", "_qore_8h.html#a85aa68ae2c985289d7426f857e0cab94", null ],
    [ "qore_cplusplus_compiler", "_qore_8h.html#a889d0fef9a14c3b8af010f54899cf2e7", null ],
    [ "qore_git_hash", "_qore_8h.html#a198a26bd1ba837a03fe2d0c79a3e0700", null ],
    [ "qore_ldflags", "_qore_8h.html#a508f7115ca9b7afd39e717c0a924236f", null ],
    [ "qore_min_mod_api_major", "_qore_8h.html#ac8b0b4d105761a37356f160dc43d469a", null ],
    [ "qore_min_mod_api_minor", "_qore_8h.html#a8bf796ea5454be80c9eec2e8cfc73a15", null ],
    [ "qore_module_dir", "_qore_8h.html#ae2a979e14a7dc2fe6d90145af605b13b", null ],
    [ "qore_module_ver_dir", "_qore_8h.html#a2b600359267eca2ad54892a1b1c64d68", null ],
    [ "qore_mpfr_info", "_qore_8h.html#ae605151efb26ed182db3e3ba17f7589e", null ],
    [ "qore_target_arch", "_qore_8h.html#a5546e4dae74dad8cc82e5df8fad0b2ad", null ],
    [ "qore_target_bits", "_qore_8h.html#a07892319abacd76008bc08af779fbd26", null ],
    [ "qore_target_os", "_qore_8h.html#a21698698cda36328f1e41b348c8cf369", null ],
    [ "qore_user_module_dir", "_qore_8h.html#a41fafaddbd9ab7c6b0ae0b4a96c15c5b", null ],
    [ "qore_user_module_ver_dir", "_qore_8h.html#a80830c640df29f1a70c152d2d579abaf", null ],
    [ "qore_version_major", "_qore_8h.html#a52951fca864ecf13261713a95415a778", null ],
    [ "qore_version_minor", "_qore_8h.html#ae94a08dda726f7123de466ef8554feaa", null ],
    [ "qore_version_string", "_qore_8h.html#a8c83964eb36898516fa586eee168ec2d", null ],
    [ "qore_version_sub", "_qore_8h.html#acae8385e006320c7cea8b1ff11821440", null ],
    [ "thread_counter", "_qore_8h.html#a407c08d8b62b6bad8610479041fc9896", null ]
];

==> qore-0.9.3.1.tar.bz2: qore-0.9.3.1/docs/library/html/_qore_8h.js <==
var _qore_8h =
[
    [ "QLO_CLEANUP_MASK", "_qore_8h.html#a775b595b770130199e61c8813e8dce0a", null ],
    [ "QLO_DISABLE_GARBAGE_COLLECTION", "_qore_8h.html#a9b922e3c858e60b05d73b49993e238f9", null ],
    [ "QLO_DISABLE_OPENSSL_CLEANUP", "_qore_8h.html#a37774985342ff0d9c2a0bbac6d8608dc", null ],
    [ "QLO_DISABLE_OPENSSL_INIT", "_qore_8h.html#ad8b4a4cef32dbf1bc16a68d5440c5c41", null ],
    [ "QLO_DISABLE_OPENSSL_INIT_CLEANUP", "_qore_8h.html#a1e6d8c51a0031fbc8647f8d7390e3213", null ],
    [ "QLO_DISABLE_SIGNAL_HANDLING", "_qore_8h.html#a07f9910d9930e441373dd9123b082bfd", null ],
    [ "QLO_DISABLE_TLS_13", "_qore_8h.html#aafb85c5aada9d3b95a15efdb8acb9835", null ],
    [ "QLO_DO_NOT_SEED_RNG", "_qore_8h.html#ae761fd26fc3572d87765af063a42ddd0", null ],
    [ "QLO_NONE", "_qore_8h.html#ab1b81a5f4b175388fb1b6d3c8bccabfb", null ],
    [ "qore_check_option", "_qore_8h.html#ad559fa513d4c8b65fb4ae91ae0a2889c", null ],
    [ "qore_cleanup", "_qore_8h.html#abec60f390fd78e61b7149586b6c00c58", null ],
    [ "qore_get_library_init_options", "_qore_8h.html#a51a38a72142d9e5c158c747e6c3c775c", null ],
    [ "qore_get_library_options", "_qore_8h.html#a926b6118e2f9b192fba95d744a7e7c6a", null ],
    [ "qore_has_debug", "_qore_8h.html#a1d1b4cc872009e7d05c23a251bac4eb4", null ],
    [ "qore_init", "_qore_8h.html#ae984b2fa9be16c83531fb954485be4ac", null ],
    [ "qore_set_library_cleanup_options", "_qore_8h.html#acf783065ef11b039c5615b6386d8f05d", null ],
    [ "qore_set_library_options", "_qore_8h.html#ae13d8c0ae5e5849306c91613b2e7160c", null ],
    [ "mpfrInfo", "_qore_8h.html#a850c8d5c2a644e5a98892bbb028ad0c4", null ],
    [ "qore_build_host", "_qore_8h.html#a355fb78ea8b9668ca413a9a802e3cdea", null ],
    [ "qore_build_number", "_qore_8h.html#a450bf7869a253a12612af9c6a564193c", null ],
    [ "qore_cflags", "_qore_8h.html#a85aa68ae2c985289d7426f857e0cab94", null ],
    [ "qore_cplusplus_compiler", "_qore_8h.html#a889d0fef9a14c3b8af010f54899cf2e7", null ],
    [ "qore_git_hash", "_qore_8h.html#a198a26bd1ba837a03fe2d0c79a3e0700", null ],
    [ "qore_ldflags", "_qore_8h.html#a508f7115ca9b7afd39e717c0a924236f", null ],
    [ "qore_min_mod_api_major", "_qore_8h.html#ac8b0b4d105761a37356f160dc43d469a", null ],
    [ "qore_min_mod_api_minor", "_qore_8h.html#a8bf796ea5454be80c9eec2e8cfc73a15", null ],
    [ "qore_module_dir", "_qore_8h.html#ae2a979e14a7dc2fe6d90145af605b13b", null ],
    [ "qore_module_ver_dir", "_qore_8h.html#a2b600359267eca2ad54892a1b1c64d68", null ],
    [ "qore_mpfr_info", "_qore_8h.html#ae605151efb26ed182db3e3ba17f7589e", null ],
    [ "qore_target_arch", "_qore_8h.html#a5546e4dae74dad8cc82e5df8fad0b2ad", null ],
    [ "qore_target_bits", "_qore_8h.html#a07892319abacd76008bc08af779fbd26", null ],
    [ "qore_target_os", "_qore_8h.html#a21698698cda36328f1e41b348c8cf369", null ],
    [ "qore_user_module_dir", "_qore_8h.html#a41fafaddbd9ab7c6b0ae0b4a96c15c5b", null ],
    [ "qore_user_module_ver_dir", "_qore_8h.html#a80830c640df29f1a70c152d2d579abaf", null ],
    [ "qore_version_major", "_qore_8h.html#a52951fca864ecf13261713a95415a778", null ],
    [ "qore_version_minor", "_qore_8h.html#ae94a08dda726f7123de466ef8554feaa", null ],
    [ "qore_version_string", "_qore_8h.html#a8c83964eb36898516fa586eee168ec2d", null ],
    [ "qore_version_sub", "_qore_8h.html#acae8385e006320c7cea8b1ff11821440", null ],
    [ "thread_counter", "_qore_8h.html#a407c08d8b62b6bad8610479041fc9896", null ]
];
